base_board_eeprom_read_b() {
    i2cget -y 1 0x50 "$1" b 2>/dev/null
}

base_board_eeprom_read_w() {
    i2cget -y 1 0x50 "$1" w 2>/dev/null | sed 's/.\{2\}/& /g' | awk -F " " '{printf $1$3$2}'
}

base_board_is_atmark_techno() {
    local is_armadillo=$(base_board_eeprom_read_w 0x00)
    if [ $is_armadillo = 0xffff ]; then
        echo "WARNING; eeprom is not initialized, please setup it."
        return
    fi
    [ "$(base_board_eeprom_read_w 0x00)" = 0x0001 ]
}

base_board_read_product_id() {
    base_board_eeprom_read_w 0x02
}

base_board_read_revision() {
    base_board_eeprom_read_w 0x0A
}

create_partitions() {
	local part start size

	# unlock the protected partition
	mmc writeprotect user set none 0 16384 /dev/mmcblk0gp0

	# We need a first non-trivial sgdisk call to "resize" the gpt,
	# otherwise partition creations fail saying there is not
	# enough space... Rerandomize disk/partition GUID.
	sgdisk -G "$DISK"

	size="$(lsblk -o SIZE -rn "$DISKPART"1)"
	sgdisk --new 2:0:+"$size" -c 2:rootfs_1 \
		--new 3:0:+50M -c 3:logs \
		--new 4:0:+200M -c 4:firm \
		--new 5:0:0 -c 5:app \
		"$DISK" \
		|| error "partitionning disk failed"
}

board_setup() {
	if ! base_board_is_atmark_techno; then
		return 0
	fi

	local board=$(base_board_read_revision)
	if [ $board = 0xffff ]; then
		board=0x0001
	fi
	einfo "board = $board"
	case "$board" in
	0x0001) echo 'iot-a6e-es1 at1' > /target/etc/hwrevision;;
	0x0002) echo 'iot-a6e-es2 at1' > /target/etc/hwrevision;;
	0x0003) echo 'iot-a6e at1' > /target/etc/hwrevision;;
	esac > /target/etc/hwrevision \
		|| error "Could not update /etc/hwrevision"

	local product_id=$(base_board_read_product_id)
	if [ $product_id = 0xffff ]; then
		product_id=0x0001
	fi
	einfo "product_id = $product_id"
	case "$product_id" in
	0x0001)
		einfo "EMS31 exists"
		echo "fdt_overlays=armadillo-iotg-a6e-ems31.dtbo" > /target/boot/overlays.txt
		ln -s /etc/init.d/ems31-boot /target/etc/runlevels/boot/
		ln -s /etc/init.d/wwan-led /target/etc/runlevels/default/
		;;
	0x0002)
		einfo "EMS31 & lwb5plus exists"
		echo "fdt_overlays=armadillo-iotg-a6e-ems31.dtbo "\
			"armadillo-iotg-a6e-lwb5plus.dtbo"  > /target/boot/overlays.txt
		ln -s /etc/init.d/ems31-boot /target/etc/runlevels/boot/
		ln -s /etc/init.d/wwan-led /target/etc/runlevels/default/
		;;
	0x0003)
		einfo "ELS31 exists"
		echo "fdt_overlays=armadillo-iotg-a6e-els31.dtbo" > /target/boot/overlays.txt
		ln -s /etc/init.d/connection-recover /target/etc/runlevels/default/
		ln -s /etc/init.d/modemmanager /target/etc/runlevels/boot/
		;;
	0x0004)
		einfo "ELS31 & lwb5plus exists"
		echo "fdt_overlays=armadillo-iotg-a6e-els31.dtbo "\
			"armadillo-iotg-a6e-lwb5plus.dtbo"  > /target/boot/overlays.txt
		ln -s /etc/init.d/connection-recover /target/etc/runlevels/default/
		ln -s /etc/init.d/modemmanager /target/etc/runlevels/boot/
		;;
	0x0006)
		einfo "lwb5plus exists"
		echo "fdt_overlays=armadillo-iotg-a6e-lwb5plus.dtbo"  > /target/boot/overlays.txt
		;;
	esac
}

get_kotai_code() {
        local skip_count=40
        dd if=/sys/bus/nvmem/devices/imx-ocotp0/nvmem \
                bs=4 skip=$skip_count count=2 status=none \
        | xxd -p \
        | sed -e 's/\(..\)\(..\)\(..\)\(..\)/\4\3\2\1/g' \
                -e 's/^... .//' \
        | tr '[:lower:]' '[:upper:]' \
        | sed 's/.*\(............\)$/\1/'
}
